#!perl

use strict;

print STDOUT "Standard Out\n";
print STDOUT "second line\n";
print STDERR "Standard Error\n";
print STDERR "another line\n";

exit(0);
